| Home | Libraries | People | FAQ | More

### is_enum

    template <class T>
    struct is_enum : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) enum type then inherits from true_type, otherwise inherits from false_type.

C++ Standard Reference: 3.9.2 and 7.2.

Header: `#include <boost/type_traits/is_enum.hpp>` or `#include <boost/type_traits.hpp>`

Compiler Compatibility: Requires a correctly functioning is_convertible template; this means that is_enum is currently broken under Borland C++ Builder 5, and for the Metrowerks compiler prior to version 8, other compilers should handle this template just fine.

Examples:

> Given: `enum my_enum { one, two };`

> `is_enum<my_enum>` inherits from `true_type`.

> `is_enum<my_enum const>::type` is the type `true_type`.

> `is_enum<my_enum>::value` is an integral constant expression that evaluates to true.

> `is_enum<my_enum&>::value` is an integral constant expression that evaluates to false.

> `is_enum<my_enum*>::value` is an integral constant expression that evaluates to false.

> `is_enum<T>::value_type` is the type `bool`.